@@ -1,6 +1,10 @@
-import torch
+import torch, os
 import numpy as np
 import pandas as pd
+
+import config
+
+os.environ["TOKENIZERS_PARALLELISM"] = "false"
 from transformers import (
     T5ForConditionalGeneration,
     MT5ForConditionalGeneration,
@@ -270,6 +274,7 @@ class LightningModel(pl.LightningModule):
             if self.current_epoch == self.trainer.max_epochs - 1:
                 self.tokenizer.save_pretrained(path)
                 self.model.save_pretrained(path)
+                config.model_path = path
         else:
             self.tokenizer.save_pretrained(path)
             self.model.save_pretrained(path)
